@@ -6,7 +6,7 @@ use Carp;
 #  Variables
 #---------------------------------------------------------------------------
 
-our $VERSION = 0.06;
+our $VERSION = 0.07;
 
 my @onshore  = qw/capital cathay iit jpmrich tisc paradigm allianz/;
 my @offshore = qw/jpmrich franklin schroders blackrock/;
@@ -26,24 +26,24 @@ sub new() {
 sub names {
     my $type = shift || q{};
     return $type eq 'onshore'  ? @onshore
-        : $type  eq 'offshore' ? @offshore
-        : @all;
+      : $type    eq 'offshore' ? @offshore
+      :                          @all;
 }
 
 sub fetch {
     my %args = @_;
-    my @all  =
-          $args{site} =~ /capital/ixm   ? $self->capital(%args)
-        : $args{site} =~ /cathay/ixm    ? $self->cathay(%args)
-        : $args{site} =~ /iit/ixm       ? $self->iit(%args)
-        : $args{site} =~ /jpmrich/ixm   ? $self->jpmrich(%args)
-        : $args{site} =~ /tisc/ixm      ? $self->tisc(%args)
-        : $args{site} =~ /franklin/ixm  ? $self->franklin(%args)
-        : $args{site} =~ /schroders/ixm ? $self->schroders(%args)
-        : $args{site} =~ /blackrock/ixm ? $self->blackrock(%args)
-        : $args{site} =~ /paradigm/ixm  ? $self->paradigm(%args)
-        : $args{site} =~ /allianz/ixm   ? $self->allianz(%args)
-        : croak "Invalid site: $args{site}\n";
+    my @all =
+        $args{site} =~ /capital/ixm   ? $self->_capital(%args)
+      : $args{site} =~ /cathay/ixm    ? $self->_cathay(%args)
+      : $args{site} =~ /iit/ixm       ? $self->_iit(%args)
+      : $args{site} =~ /jpmrich/ixm   ? $self->_jpmrich(%args)
+      : $args{site} =~ /tisc/ixm      ? $self->_tisc(%args)
+      : $args{site} =~ /franklin/ixm  ? $self->_franklin(%args)
+      : $args{site} =~ /schroders/ixm ? $self->_schroders(%args)
+      : $args{site} =~ /blackrock/ixm ? $self->_blackrock(%args)
+      : $args{site} =~ /paradigm/ixm  ? $self->_paradigm(%args)
+      : $args{site} =~ /allianz/ixm   ? $self->_allianz(%args)
+      :                                 croak "Invalid site: $args{site}\n";
 
     my @result = $args{name} ? grep { $_->{name} =~ $args{name} } @all : @all;
     return wantarray ? @result : \@result;
@@ -52,60 +52,60 @@ sub fetch {
 sub fetch_all {
     my $type = shift || q{};
     my @array =
-          $type eq 'onshore'  ? @onshore
-        : $type eq 'offshore' ? @offshore
-        : @all;
-    my %result
-        = map { $_ => [ $self->fetch( site => $_, type => $type ) ] } @array;
+        $type eq 'onshore'  ? @onshore
+      : $type eq 'offshore' ? @offshore
+      :                       @all;
+    my %result =
+      map { $_ => [ $self->fetch( site => $_, type => $type ) ] } @array;
     return wantarray ? %result : \%result;
 }
 
-sub allianz {
+sub _allianz {
     require Finance::QuoteTW::Allianz;
     return Finance::QuoteTW::Allianz::fetch( $self, @_ );
 }
 
-sub paradigm {
+sub _paradigm {
     require Finance::QuoteTW::Paradigm;
     return Finance::QuoteTW::Paradigm::fetch( $self, @_ );
 }
 
-sub capital {
+sub _capital {
     require Finance::QuoteTW::Capital;
     return Finance::QuoteTW::Capital::fetch( $self, @_ );
 }
 
-sub cathay {
+sub _cathay {
     require Finance::QuoteTW::Cathay;
     return Finance::QuoteTW::Cathay::fetch( $self, @_ );
 }
 
-sub iit {
+sub _iit {
     require Finance::QuoteTW::Iit;
     return Finance::QuoteTW::Iit::fetch( $self, @_ );
 }
 
-sub jpmrich {
+sub _jpmrich {
     require Finance::QuoteTW::Jpmrich;
     return Finance::QuoteTW::Jpmrich::fetch( $self, @_ );
 }
 
-sub tisc {
+sub _tisc {
     require Finance::QuoteTW::Tisc;
     return Finance::QuoteTW::Tisc::fetch( $self, @_ );
 }
 
-sub franklin {
+sub _franklin {
     require Finance::QuoteTW::Franklin;
     return Finance::QuoteTW::Franklin::fetch( $self, @_ );
 }
 
-sub schroders {
+sub _schroders {
     require Finance::QuoteTW::Schroders;
     return Finance::QuoteTW::Schroders::fetch( $self, @_ );
 }
 
-sub blackrock {
+sub _blackrock {
     require Finance::QuoteTW::Blackrock;
     return Finance::QuoteTW::Blackrock::fetch( $self, @_ );
 }
